==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/uk.php <==
<?php $TRANSLATIONS = array(
"New Timezone:" => "Новий часовий пояс",
"Timezone changed" => "Часовий пояс змінено",
"Calendar" => "Календар",
"Birthday" => "День народження",
"Business" => "Справи",
"Call" => "Подзвонити",
"Clients" => "Клієнти",
"Holidays" => "Свята",
"Ideas" => "Ідеї",
"Journey" => "Поїздка",
"Jubilee" => "Ювілей",
"Meeting" => "Зустріч",
"Other" => "Інше",
"Personal" => "Особисте",
"Projects" => "Проекти",
"Questions" => "Запитання",
"Work" => "Робота",
"Does not repeat" => "Не повторювати",
"Daily" => "Щоденно",
"Weekly" => "Щотижня",
"Every Weekday" => "По будням",
"Bi-Weekly" => "Кожні дві неділі",
"Monthly" => "Щомісяця",
"Yearly" => "Щорічно",
"never" => "ніколи",
"Monday" => "Понеділок",
"Tuesday" => "Вівторок",
"Wednesday" => "Середа",
"Thursday" => "Четвер",
"Friday" => "П'ятниця",
"Saturday" => "Субота",
"Sunday" => "Неділя",
"first" => "перший",
"second" => "другий",
"third" => "третій",
"fourth" => "четвертий",
"fifth" => "п'ятий",
"last" => "останній",
"January" => "Січень",
"February" => "Лютий",
"March" => "Березень",
"April" => "Квітень",
"May" => "Травень",
"June" => "Червень",
"July" => "Липень",
"August" => "Серпень",
"September" => "Вересень",
"October" => "Жовтень",
"November" => "Листопад",
"December" => "Грудень",
"Date" => "Дата",
"Cal." => "Кал.",
"All day" => "Увесь день",
"New Calendar" => "новий Календар",
"Title" => "Назва",
"Week" => "Тиждень",
"Month" => "Місяць",
"List" => "Список",
"Today" => "Сьогодні",
"Calendars" => "Календарі",
"There was a fail, while parsing the file." => "Сталася помилка при обробці файлу",
"Choose active calendars" => "Вибрати активні календарі",
"Download" => "Завантажити",
"Edit" => "Редагувати",
"New calendar" => "Новий календар",
"Edit calendar" => "Редагувати календар",
"Active" => "Активний",
"Calendar color" => "Колір календаря",
"Title of the Event" => "Назва події",
"Category" => "Категорія",
"From" => "З",
"To" => "По",
"Location" => "Місце",
"Location of the Event" => "Місце події",
"Description" => "Опис",
"Description of the Event" => "Опис події",
"Repeat" => "Повторювати",
"Import a calendar file" => "Імпортувати файл календаря",
"create a new calendar" => "створити новий календар",
"Name of new calendar" => "Назва нового календаря",
"Calendar imported successfully" => "Календар успішно імпортовано",
"Create a new event" => "Створити нову подію",
"Timezone" => "Часовий пояс",
"Timeformat" => "Формат часу",
"24h" => "24г",
"12h" => "12г",
"Calendar CalDAV syncing address:" => "Адреса синхронізації календаря CalDAV:"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/uk.php <==
<?php $TRANSLATIONS = array(
"New Timezone:" => "Новий часовий пояс",
"Timezone changed" => "Часовий пояс змінено",
"Calendar" => "Календар",
"Birthday" => "День народження",
"Business" => "Справи",
"Call" => "Подзвонити",
"Clients" => "Клієнти",
"Holidays" => "Свята",
"Ideas" => "Ідеї",
"Journey" => "Поїздка",
"Jubilee" => "Ювілей",
"Meeting" => "Зустріч",
"Other" => "Інше",
"Personal" => "Особисте",
"Projects" => "Проекти",
"Questions" => "Запитання",
"Work" => "Робота",
"New Calendar" => "новий Календар",
"Does not repeat" => "Не повторювати",
"Daily" => "Щоденно",
"Weekly" => "Щотижня",
"Every Weekday" => "По будням",
"Bi-Weekly" => "Кожні дві неділі",
"Monthly" => "Щомісяця",
"Yearly" => "Щорічно",
"never" => "ніколи",
"Monday" => "Понеділок",
"Tuesday" => "Вівторок",
"Wednesday" => "Середа",
"Thursday" => "Четвер",
"Friday" => "П'ятниця",
"Saturday" => "Субота",
"Sunday" => "Неділя",
"first" => "перший",
"second" => "другий",
"third" => "третій",
"fourth" => "четвертий",
"fifth" => "п'ятий",
"last" => "останній",
"January" => "Січень",
"February" => "Лютий",
"March" => "Березень",
"April" => "Квітень",
"May" => "Травень",
"June" => "Червень",
"July" => "Липень",
"August" => "Серпень",
"September" => "Вересень",
"October" => "Жовтень",
"November" => "Листопад",
"December" => "Грудень",
"Date" => "Дата",
"Cal." => "Кал.",
"All day" => "Увесь день",
"Missing fields" => "Пропущені поля",
"Title" => "Назва",
"From Date" => "Від Дати",
"From Time" => "З Часу",
"To Date" => "До Часу",
"To Time" => "По Дату",
"The event ends before it starts" => "Подія завершається до її початку",
"There was a database fail" => "Сталася помилка бази даних",
"Week" => "Тиждень",
"Month" => "Місяць",
"List" => "Список",
"Today" => "Сьогодні",
"Your calendars" => "Ваші календарі",
"Download" => "Завантажити",
"Edit" => "Редагувати",
"Delete" => "Видалити",
"New calendar" => "Новий календар",
"Edit calendar" => "Редагувати календар",
"Active" => "Активний",
"Calendar color" => "Колір календаря",
"Save" => "Зберегти",
"Cancel" => "Відмінити",
"Export" => "Експорт",
"Title of the Event" => "Назва події",
"Category" => "Категорія",
"From" => "З",
"To" => "По",
"Location" => "Місце",
"Location of the Event" => "Місце події",
"Description" => "Опис",
"Description of the Event" => "Опис події",
"Repeat" => "Повторювати",
"create a new calendar" => "створити новий календар",
"Import a calendar file" => "Імпортувати файл календаря",
"Name of new calendar" => "Назва нового календаря",
"Import" => "Імпорт",
"Create a new event" => "Створити нову подію",
"Timezone" => "Часовий пояс",
"24h" => "24г",
"12h" => "12г"
);
